summaryrefslogtreecommitdiffstats
path: root/kmail/kmservertest.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kmail/kmservertest.cpp')
-rw-r--r--kmail/kmservertest.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/kmail/kmservertest.cpp b/kmail/kmservertest.cpp
index 67dc0f2d5..c7f96ce36 100644
--- a/kmail/kmservertest.cpp
+++ b/kmail/kmservertest.cpp
@@ -112,17 +112,17 @@ void KMServerTest::slotData(KIO::Job *, const TQString &data)
void KMServerTest::slotMetaData( const KIO::MetaData & md ) {
- KIO::MetaData::const_iterator it = md.tqfind( "PLAIN AUTH METHODS" );
+ KIO::MetaData::const_iterator it = md.find( "PLAIN AUTH METHODS" );
if ( it != md.end() ) {
mAuthNone = it.data();
kdDebug(5006) << "mAuthNone: " << mAuthNone << endl;
}
- it = md.tqfind( "TLS AUTH METHODS" );
+ it = md.find( "TLS AUTH METHODS" );
if ( it != md.end() ) {
mAuthTLS = it.data();
kdDebug(5006) << "mAuthTLS: " << mAuthTLS << endl;
}
- it = md.tqfind( "SSL AUTH METHODS" );
+ it = md.find( "SSL AUTH METHODS" );
if ( it != md.end() ) {
mAuthSSL = it.data();
kdDebug(5006) << "mAuthSSL: " << mAuthSSL << endl;
@@ -142,7 +142,7 @@ void KMServerTest::slotSlaveResult(KIO::Slave *aSlave, int error,
if (aSlave != mSlave) return;
if ( mSSL && error == 0 ) {
// add a dummy entry to the list of SSL capabilities so that the receiver
// of the capabilities signal can use mListSSL.isEmpty() in order to tqfind
// out whether SSL is supported
mListSSL.append("SSL");
}
@@ -142,7 +142,7 @@ void KMServerTest::slotSlaveResult(KIO::Slave *aSlave, int error,
if ( mSSL && error == 0 ) {
// add a dummy entry to the list of SSL capabilities so that the receiver
- // of the capabilities signal can use mListSSL.isEmpty() in order to tqfind
+ // of the capabilities signal can use mListSSL.isEmpty() in order to find
// out whether SSL is supported
mListSSL.append("SSL");